Disclosures/Text
================

It is easy to access the contents of SEC filings from Calcbench.

Calcbench parses the sections of the 10-K/Q such as Management's Discussion and Analysis and Risk Factors.  See the list of available sections @ https://www.calcbench.com/disclosure_list

.. automodule:: calcbench.disclosures
    :members:
    :undoc-members: